@@ -24,13 +24,14 @@
 #'@param fisher Fisher's exact test. The default is FALSE.
 #'@param correct Chi square test for continuity correction.The default is FALSE.
 #'@param Overall Generate summary data.The default is FALSE.
+#'@param smd The default is FALSE. If it is true, return the SMD value.
 #'
 #'@return A data frame.
 #'
 #'
 #'@format NULL
 #'@usage scitb1(vars,fvars=NULL,strata,data,dec,num,nonnormal=NULL,type=NULL,
-#'statistic=F,atotest=T,NormalTest=NULL,fisher=FALSE,correct=FALSE,Overall=FALSE)
+#'statistic=F,atotest=T,NormalTest=NULL,fisher=FALSE,correct=FALSE,Overall=FALSE,smd=FALSE)
 #'@export
 #'@examples
 #'## Import data
@@ -44,6 +45,7 @@
 #'out<-scitb1(vars=allVars,fvars=fvars,strata=strata,data=bc)
 #'out<-scitb1(vars=allVars,fvars=fvars,strata=strata,data=bc,statistic=TRUE)
 #'out<-scitb1(vars=allVars,fvars=fvars,strata=strata,data=bc,statistic=TRUE,Overall=TRUE)
+#'out<-scitb1(vars=allVars,fvars=fvars,strata=strata,data=bc,statistic=TRUE,Overall=TRUE,smd=TRUE)
 #'print(out)
 #'
 #'###Stratified variables are continuous variables.
@@ -52,7 +54,7 @@
 #'strata<-"age"
 #'out<-scitb1(vars=allVars,fvars=fvars,strata=strata,data=bc)
 #'out<-scitb1(vars=allVars,fvars=fvars,strata=strata,data=bc,statistic=TRUE)
-#'out<-scitb1(vars=allVars,fvars=fvars,strata=strata,data=bc,statistic=TRUE,Overall=TRUE)
+#'out<-scitb1(vars=allVars,fvars=fvars,strata=strata,data=bc,statistic=TRUE,Overall=TRUE,smd=TRUE)
 #'print(out)
 #'
 
@@ -60,7 +62,8 @@
 
 
 scitb1<-function(vars,fvars=NULL,strata,data,dec,num,nonnormal=NULL,type=NULL,
-                 statistic=F,atotest=T,NormalTest=NULL,fisher=FALSE,correct=FALSE,Overall=FALSE) {
+                 statistic=F,atotest=T,NormalTest=NULL,fisher=FALSE,
+                 correct=FALSE,Overall=FALSE,smd=FALSE) {
   if (missing(vars)) {stop("Missing vars.")}
   if (missing(strata)) {stop("Missing strata.")}
   if (missing(data)) {stop("Missing data.")}
@@ -69,7 +72,7 @@ scitb1<-function(vars,fvars=NULL,strata,data,dec,num,nonnormal=NULL,type=NULL,
   if (missing(num)) {num<-3} else {num<-num}
   if (missing(type)) {type<-"A"} else {type<-type}
   strata<-strata;NormalTest<-NormalTest;statistic<-statistic;
-  atotest<-atotest;correct<-correct;Overall<-Overall;fisher<-fisher
+  atotest<-atotest;correct<-correct;Overall<-Overall;fisher<-fisher;smd<-smd
   if (!is.factor(data[,strata]) & length(levels(factor(data[,strata]))) >5 ) {
     G<-rankvar(data[,strata],num=num)
     data$G<-G
@@ -80,19 +83,20 @@ scitb1<-function(vars,fvars=NULL,strata,data,dec,num,nonnormal=NULL,type=NULL,
   if (!is.null(fvars)) {
     if (identical(vars,fvars)) {
       fout<-sci1freq(mvars=fvars,x=strata,data=data,nonnormal=nonnormal,dec=dec,
-                     statistic=statistic,correct=correct,Overall=Overall,fisher=fisher)
-      dat<-fout
+                     statistic=statistic,correct=correct,Overall=Overall,fisher=fisher,smd=smd)
+      dat<-fout[["data"]]
     } else {
       fout<-sci1freq(mvars=fvars,x=strata,data=data,nonnormal=nonnormal,dec=dec,
-                     statistic=statistic,correct=correct,Overall=Overall,fisher=fisher)
+                     statistic=statistic,correct=correct,Overall=Overall,fisher=fisher,smd=smd)
       mout<-sci1mean(mvars=mvars,x=strata,data=data,nonnormal=nonnormal,dec=dec,
-                     type=type,statistic=statistic,atotest=atotest,NormalTest=NormalTest,Overall=Overall)
-      dat<-rbind(mout,fout)
+                     type=type,statistic=statistic,atotest=atotest,
+                     NormalTest=NormalTest,Overall=Overall,smd=smd)
+      dat<-rbind(mout[["data"]],fout[["data"]])
     }
   } else {
     mout<-sci1mean(mvars=mvars,x=strata,data=data,nonnormal=nonnormal,dec=dec,type=type,
-                   statistic=statistic,atotest=atotest,NormalTest=NormalTest,Overall=Overall)
-    dat<-mout
+                   statistic=statistic,atotest=atotest,NormalTest=NormalTest,Overall=Overall,smd=smd)
+    dat<-mout[["data"]]
   }
   dat
 }
